@@ -211,6 +211,20 @@ class AppHandler(object):
         return value
 
     def get_setting(self, session, name, typ=None, **kwargs):
+        """
+        Get a setting value from the DB.
+
+        :param session: Current DB session.
+
+        :param name: Name of the setting to save.
+
+        :param typ: Most values are treated as simple strings, but if
+           you specify ``'utctime'`` here, then the return value will
+           be converted to a UTC-based ``datetime`` object
+
+        :returns: Usually a string, but can be some other type,
+           depending on the ``typ`` param.
+        """
         model = self.model
         setting = session.query(model.Setting).get(name)
         value = None if setting is None else setting.value
@@ -223,7 +237,28 @@ class AppHandler(object):
 
         return value
 
-    def save_setting(self, session, name, value, typ=None, **kwargs):
+    def save_setting(self, session, name, value, typ=None,
+                     force_create=False, **kwargs):
+        """
+        Save a setting value to the DB.
+
+        :param session: Current DB session.
+
+        :param name: Name of the setting to save.
+
+        :param value: Value to be saved for the setting.
+
+        :param typ: Most values are treated as simple strings, but if
+           you specify ``'utctime'`` here, then the ``value`` is
+           assumed to be a UTC-based ``datetime`` object, and the
+           final setting value will be formatted appropriately.
+
+        :param force_create: If ``False`` (the default) then logic
+           will first try to locate an existing setting of the given
+           name, and update it if found, or create if not.  But if
+           this param is ``True`` then logic will only try to create a
+           new record, and not bother checking to see if it exists.
+        """
         model = self.model
 
         if typ == 'utctime':
@@ -232,7 +267,10 @@ class AppHandler(object):
             else:
                 value = None
 
-        setting = session.query(model.Setting).get(name)
+        # create or update the setting
+        setting = None
+        if not force_create:
+            setting = session.query(model.Setting).get(name)
         if not setting:
             setting = model.Setting(name=name)
             session.add(setting)
@@ -242,11 +280,21 @@ class AppHandler(object):
         self.config.beaker_invalidate_setting(name)
 
     def delete_setting(self, session, name, **kwargs):
+        """
+        Delete the given setting from the DB.
+
+        :param session: Current DB session.
+
+        :param name: Name of the setting to delete.
+        """
         model = self.model
         setting = session.query(model.Setting).get(name)
         if setting:
             session.delete(setting)
 
+        # invalidate beaker config cache for this setting, if applicable
+        self.config.beaker_invalidate_setting(name)
+
     def touch_object(self, session, obj):
         """
         Mark the given object as having been changed, such that the
