@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -107,17 +107,10 @@ class ProductNewOrderAutocompleter(ProductAutocompleter):
     it will try to search for *both* UPC (or whatever your "key" is)
     *and* product brand, description etc.  The UPC (key) must match
     "exactly" whereas the description etc. uses wildcard search.
-
-    .. attribute:: lookup_only_keys
-
-       You can set this to an explicit list of product "keys" to
-       restrict which types of lookups are performed for that.
-
      """
     autocompleter_key = 'products.neworder'
     model_class = model.Product
     autocomplete_fieldname = 'description'
-    lookup_only_keys = []
 
     def get_autocomplete_data(self, session, term, **kwargs):
         """
@@ -131,8 +124,7 @@ class ProductNewOrderAutocompleter(ProductAutocompleter):
         and will be limited.
         """
         # first run the product "key" query, and save matches for later
-        self.key_matches = self.find_product_key_matches(session, term,
-                                                         include_keys=True)
+        self.key_matches = self.find_product_key_matches(session, term)
 
         # then run the "normal" upstream query to get data from the
         # wildcard search.  note that this will be results-limited
@@ -150,8 +142,7 @@ class ProductNewOrderAutocompleter(ProductAutocompleter):
         data = super(ProductNewOrderAutocompleter, self).get_autocomplete_results(data)
 
         # then inject key matches at the beginning
-        for i, match in enumerate(self.key_matches):
-            key, product = match
+        for i, product in enumerate(self.key_matches):
             data.insert(i, {'label': self.autocomplete_display(product),
                             'value': self.autocomplete_value(product)})
 
@@ -164,7 +155,8 @@ class ProductNewOrderAutocompleter(ProductAutocompleter):
         Usually this just means finding a UPC match.
         """
         handler = self.app.get_products_handler()
-        if 'only' not in kwargs and self.lookup_only_keys:
-            kwargs['only'] = self.lookup_only_keys
-        products = handler.find_products_by_key(session, term, **kwargs)
+        products = []
+        product = handler.locate_product_for_key(session, term)
+        if product:
+            products.append(product)
         return products
