@@ -592,60 +592,6 @@ class DateOrganize(Subcommand):
                     shutil.move(path, datedir)
 
 
-class Dump(Subcommand):
-    """
-    Do a simple data dump.
-    """
-
-    name = 'dump'
-    description = "Dump data to file."
-
-    def add_parser_args(self, parser):
-        parser.add_argument(
-            '--output', '-o', metavar='FILE',
-            help="Optional path to output file.  If none is specified, "
-            "data will be written to standard output.")
-        parser.add_argument(
-            'model', help="Model whose data will be dumped.")
-
-    def get_model(self):
-        """
-        Returns the module which contains all relevant data models.
-
-        By default this returns ``rattail.db.model``, but this method may be
-        overridden in derived commands to add support for extra data models.
-        """
-        from rattail.db import model
-        return model
-
-    def run(self, args):
-        from rattail.db import Session
-        from rattail.db.dump import dump_data
-
-        model = self.get_model()
-        if hasattr(model, args.model):
-            cls = getattr(model, args.model)
-        else:
-            self.stderr.write("Unknown model: {0}\n".format(args.model))
-            sys.exit(1)
-
-        progress = None
-        if self.show_progress: # pragma no cover
-            progress = ConsoleProgress
-
-        if args.output:
-            output = open(args.output, 'wb')
-        else:
-            output = self.stdout
-
-        session = Session()
-        dump_data(session, cls, output, progress=progress)
-        session.close()
-
-        if output is not self.stdout:
-            output.close()
-
-
 class FileMonitorCommand(Subcommand):
     """
     Interacts with the file monitor service; called as ``rattail filemon``.
@@ -805,27 +751,6 @@ class MailMonitorCommand(Subcommand):
                 self.stderr.write("Interrupted.\n")
 
 
-class LoadHostDataCommand(Subcommand):
-    """
-    Loads data from the Rattail host database, if one is configured.
-    """
-
-    name = 'load-host-data'
-    description = "Load data from host database"
-
-    def run(self, args):
-        from .db import get_engines
-        from .db import load
-
-        engines = get_engines(self.config)
-        if 'host' not in engines:
-            sys.stderr.write("Host engine URL not configured.\n")
-            sys.exit(1)
-
-        proc = load.LoadProcessor(self.config)
-        proc.load_all_data(engines['host'], ConsoleProgress)
-
-
 class MakeAppDir(Subcommand):
     """
     Create a conventional 'app' dir for a virtual environment
@@ -889,18 +814,37 @@ class MakeConfig(Subcommand):
                             "be the full path including filename, or just the folder, in which "
                             "case the filename is inferred from 'type'.  Default is to current "
                             "working folder.")
+        parser.add_argument('--list-types', action='store_true',
+                            help="List the types of config files this tool can "
+                            "generate.")
 
     def run(self, args):
+        if args.list_types:
+            self.list_types()
+            return
+
         template_path = self.app.find_config_template(args.type)
         if not template_path:
             self.stderr.write("config template not found for type: {}\n".format(args.type))
             sys.exit(1)
 
         output_path = os.path.abspath(args.output)
+        if os.path.exists(output_path):
+            self.stderr.write("ERROR! output file already exists: {}\n".format(output_path))
+            sys.exit(2)
+
         config_path = self.app.make_config_file(args.type, output_path,
                                                 template_path=template_path)
         self.stdout.write("Config file generated at: {}\n".format(config_path))
 
+    def list_types(self):
+        templates = self.app.get_all_config_templates()
+        self.stdout.write("CONFIG TEMPLATES:\n")
+        self.stdout.write("=========================\n")
+        for name, path in six.iteritems(templates):
+            self.stdout.write("{:25s} {}\n".format(name, path))
+        self.stdout.write("=========================\n")
+
 
 class MakeUser(Subcommand):
     """
