@@ -28,6 +28,8 @@ from __future__ import unicode_literals, absolute_import
 
 import warnings
 
+import six
+
 from rattail import importing
 from rattail.db import Session
 from rattail.config import parse_list
@@ -78,6 +80,13 @@ class DataSyncConsumer(object):
            (which the default logic does) then the original set of
            changes will be processed.
         """
+        # declare responsible user
+        if self.runas_username:
+            session.set_continuum_user(self.runas_username)
+
+        # update all importers with current Rattail session
+        for importer in six.itervalues(self.importers):
+            importer.session = session
 
     def process_changes(self, session, changes):
         """
@@ -247,13 +256,6 @@ class DataSyncImportConsumer(DataSyncConsumer):
         if result is not None:
             changes = result
 
-        if self.runas_username:
-            session.set_continuum_user(self.runas_username)
-
-        # Update all importers with current Rattail session.
-        for importer in self.importers.values():
-            importer.session = session
-
         for change in changes:
             self.invoke_importer(session, change)
 
