@@ -54,7 +54,7 @@ from .vendors import Vendor, VendorPhoneNumber, VendorEmailAddress, VendorContac
 from .products import (UnitOfMeasure, Brand, Tax, Product, ProductImage, ProductCode,
                        ProductCost, ProductFutureCost, ProductPrice,
                        ProductInventory, ProductStoreInfo, ProductVolatile,
-                       InventoryAdjustmentReason)
+                       PendingProduct, InventoryAdjustmentReason)
 from .ifps import IFPS_PLU
 from .purchase import (PurchaseBase, PurchaseItemBase, PurchaseCreditBase,
                        Purchase, PurchaseItem, PurchaseCredit)
