@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -291,7 +291,11 @@ class CustomerGroupAssignment(Base):
     group_uuid = sa.Column(sa.String(length=32), nullable=False)
     ordinal = sa.Column(sa.Integer(), nullable=False)
 
-    group = orm.relationship(CustomerGroup)
+    group = orm.relationship(
+        CustomerGroup,
+        backref=orm.backref(
+            '_customers',
+            cascade='all, delete-orphan'))
 
 
 Customer._groups = orm.relationship(
